/*
    Copyright 2009 Luigi Auriemma

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA

    http://www.gnu.org/licenses/gpl-2.0.txt
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "idea.c"

#ifdef WIN32
#else
    #define stristr strcasestr
#endif

typedef unsigned char   u8;



#define VER     "0.1"



int hex2byte(u8 *str) {
    int     i,
            n;
    u8      *p;

    p = str;
    for(i = 0; *p; i++, p += 2) {
        if(sscanf(p, "%02X", &n) != 1) break;
        str[i] = n;
    }
    return(i);
}



void orbit_decrypt(u8 *pwd) {
    IDEA_context    ctx;
    int     i,
            len;

    len = hex2byte(pwd);

    do_setkey(&ctx, "\x13\x17\x38\x17\x1c\x63\x0b\x6f\x62\x0d\x0b\x06\x79\x22\x11\x4c", 16);
    for(i = 0; i < len; i += 8) {
        decrypt_block(&ctx, pwd + i, pwd + i);
    }
    len = (pwd[len - 1] + len - 8);
    pwd[len] = 0;
}



void wait_exit(int ret) {
    fprintf(stderr, "\npress RETURN to exit\n");
    fgetc(stdin);
    exit(ret);
}



void std_err(void) {
    perror("\nError");
    wait_exit(1);
}



int main(int argc, char *argv[]) {
    FILE    *fd;
    u8      buff[1024],
            *fname,
            *p;

    fputs("\n"
        "Orbit Downloader password decrypter "VER"\n"
        "by Luigi Auriemma\n"
        "e-mail: aluigi@autistici.org\n"
        "web:    aluigi.org\n"
        "\n", stdout);

    if(argc < 2) {
        printf("\n"
            "Usage: %s <sitelogin.dat/password>\n"
            "\n", argv[0]);
        wait_exit(1);
    }
    fname = argv[1];

    fd = fopen(fname, "rb");
    if(!fd) {
        p = strdup(fname);  // not needed
        orbit_decrypt(p);
        printf("\n  PASSWORD: %s\n", p);
    } else {
        while(fgets(buff, sizeof(buff), fd)) {
            for(p = buff; *p && (*p != '\r') && (*p != '\n'); p++);
            *p = 0;

            p = strchr(buff, '=');
            if(!p) continue;
            *p++ = 0;
            if(stristr(buff, "password")) {
                orbit_decrypt(p);
                printf("  %-10s %s\n", buff, p);
            } else if(stristr(buff, "user")) {
                printf("  %-10s %s\n", buff, p);
            } else if(stristr(buff, "site")) {
                printf("\n  %-10s %s\n", buff, p);
            }
        }
        fclose(fd);
    }

    wait_exit(0);
    return(0);
}


